@@ -317,7 +317,11 @@ class CategoricalVariableImputer(BaseImputer):
     ----------
 
     imputation_method : str, default=missing
-        Desired method of imputation. Can take 'missing' or 'frequent'.
+        Desired method of imputation. Can be 'frequent' or 'missing'.
+        
+    fill_value : str, default='Missing'
+        Only used when imputation_method='missing'. Can be used to set a 
+        user-defined value to replace the missing data.
 
     variables : list, default=None
         The list of variables to be imputed. If None, the imputer will find and
@@ -333,12 +337,16 @@ class CategoricalVariableImputer(BaseImputer):
         with feature-engine.
     """
 
-    def __init__(self, imputation_method='missing', variables=None, return_object=False):
-
+    def __init__(self, imputation_method='missing', fill_value='Missing', variables=None, return_object=False):
+        
         if imputation_method not in ['missing', 'frequent']:
             raise ValueError("imputation_method takes only values 'missing' or 'frequent'")
-
+        
+        if not isinstance(fill_value, str):
+            raise ValueError("parameter 'fill_value' should be string")
+        
         self.imputation_method = imputation_method
+        self.fill_value = fill_value
         self.variables = _define_variables(variables)
         self.return_object = return_object
 
@@ -369,10 +377,9 @@ class CategoricalVariableImputer(BaseImputer):
 
         # find or check for categorical variables
         self.variables = _find_categorical_variables(X, self.variables)
-
-        # find imputation parameters
+        
         if self.imputation_method == 'missing':
-            self.imputer_dict_ = {var: 'Missing' for var in self.variables}
+            self.imputer_dict_ = {var: self.fill_value for var in self.variables}
 
         elif self.imputation_method == 'frequent':
             self.imputer_dict_ = {}
